@@ -2,21 +2,20 @@ from pathlib import Path
 from typing import Dict
 
 import numpy as np
-from lazy import lazy
-
-from evobench.benchmark import Benchmark
+from evobench.discrete import Discrete
 from evobench.model import Solution
+from lazy import lazy
 
 from .config import Config
 from .parser import load
 
 
-class IsingSpinGlass(Benchmark):
+class IsingSpinGlass(Discrete):
 
     def __init__(
         self,
         config_name: str,
-        shuffle: bool = False,
+        use_shuffle: bool = False,
         multiprocessing: bool = False,
         verbose: int = 0
     ):
@@ -32,7 +31,11 @@ class IsingSpinGlass(Benchmark):
             _P3_ repository.
         """
 
-        super(IsingSpinGlass, self).__init__(shuffle, multiprocessing, verbose)
+        super(IsingSpinGlass, self).__init__(
+            use_shuffle,
+            multiprocessing,
+            verbose
+        )
         self.config_name = config_name
 
     @lazy
@@ -44,11 +47,7 @@ class IsingSpinGlass(Benchmark):
         return load(path)
 
     @lazy
-    def global_opt(self) -> float:
-        return 1
-
-    @lazy
-    def dsm(self) -> np.ndarray:
+    def true_dsm(self) -> np.ndarray:
         dsm = np.eye(self.config.genome_size)
 
         for spin in self.config.spins:
@@ -71,25 +70,6 @@ class IsingSpinGlass(Benchmark):
 
         return as_dict
 
-    @lazy
-    def lower_bound(self) -> np.ndarray:
-        lower_bound = [0.0] * self.genome_size
-        return np.array(lower_bound)
-
-    @lazy
-    def upper_bound(self) -> np.ndarray:
-        upper_bound = [1.0] * self.genome_size
-        return np.array(upper_bound)
-
-    def random_solution(self) -> Solution:
-        genome = np.random.uniform(low=0, high=2, size=self.genome_size)
-
-        genome *= self.bound_range
-        genome -= self.lower_bound
-        genome = genome.astype(dtype=np.int)
-
-        return Solution(genome)
-
     def _evaluate_solution(self, solution: Solution) -> float:
 
         energy = 0.0
